/*********************************************************************
*                                                                    *          
*                              FLY                                   *
*                           --E#Y#E--   			     *
*                         ===MUSCLE===                               *
*                                                                    *
*********************************************************************/
/* Header Files */
#include "cockpit.h"

/* View */
#define COK 
#define MOT 
#define ZYL

/* Cockpit */
GLfloat viewZ;
GLfloat rootY;
GLfloat nightV;
GLfloat scaPlane;

/* Motor */
char zylinder;
GLfloat zylscale1;
GLfloat zylscale2;
GLfloat maxLimit =  -0.00f;
GLfloat minLimit =  -0.03f;

/*---------------------------------------------------------------------------*/

/* CameraLook */
void CameraLook()
{
	/* Identity */
	glLoadIdentity();
	glTranslatef(0.0, 0.0, 0.0);

	/* Camera Look */
	gluLookAt(0.0f, 2.0f, 20.0f, 
		  0.0f, 2.0f,-20.0f, 
		  0.0f, 5.0f, 0.0f);
}

/*---------------------------------------------------------------------------*/

/* Plane */
void Plane(GLfloat xPlane, GLfloat yPlane, GLfloat zPlane)
{	
	/* Variables */
	GLfloat xScaling = 1.0f;
	GLfloat yScaling = 1.0f;
	GLfloat zScaling = 1.0f;
	
	/* Scaling */
	glScalef(xScaling +scaPlane, yScaling +scaPlane, zScaling +scaPlane);

        /* Rotation */
        xPlane = cos(xPlane) + (-sin(yPlane));
        yPlane = sin(xPlane) + cos(yPlane);

	/* Translate */
	glTranslatef(cos(xPlane), sin(yPlane) + 2.0f, zPlane + viewZ + 18.499f);
	glTranslatef( -cos(xPlane), -sin(yPlane), -zPlane);
}

/*---------------------------------------------------------------------------*/

/* Speed */
void Speed(float dt)
{
        const float speed = 0.001f;
      
        /* Speed */
        if(zylinder)
        {
                  zylscale1 += speed;
                  zylscale2 -= speed;
        }
        else
        {
                  zylscale1 -= speed;
                  zylscale2 += speed;
        }
      
        /* Limit */
        if(zylscale1 >= maxLimit)
        {
                  zylinder = FALSE;
        }
        else if(zylscale1 <= minLimit)
        {
                  zylinder = TRUE;
        }
}

/*---------------------------------------------------------------------------*/

/* 9 Zylinder */
void Zylinder()
{
	/* PlaneView */
	CameraLook();
	Plane(xPlane, yPlane, zPlane);
	
	/* Line & Point */
	glLineWidth(2);
	glPointSize(20);

	/* Raudis */
	#ifdef ZYL
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_QUADS);
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( -0.4f,  -0.399f, -0.1f );
		glVertex3f(  0.4f,  -0.399f, -0.1f );
		glVertex3f(  0.4f,  -0.399f, -0.9f );
		glVertex3f( -0.4f,  -0.399f, -0.9f );
	glEnd();

	/* 9 Zylinder */
        glRotatef(-zylscale1, 0.1f, 0.0f, 0.0f);
        glRotatef(-zylscale2, 0.1f, 0.0f, 0.0f);
	glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
	glBegin(GL_POINTS);
	        glColor4f(0.30f, 0.30f, 0.30f, 1.0f);
	        glVertex3f( 0.30f, -0.40f -zylscale1, -0.20f );
	        glVertex3f( 0.00f, -0.37f -zylscale2, -0.20f );
	        glVertex3f(-0.30f, -0.40f -zylscale1, -0.20f );
	      
	        glVertex3f( 0.30f, -0.37f -zylscale2, -0.50f );
	        glVertex3f( 0.00f, -0.40f -zylscale1, -0.50f );
	        glVertex3f(-0.30f, -0.37f -zylscale2, -0.50f );
	        
	        glVertex3f( 0.30f, -0.40f -zylscale1, -0.80f );
	        glVertex3f( 0.00f, -0.37f -zylscale2, -0.80f );
	        glVertex3f(-0.30f, -0.40f -zylscale1, -0.80f );
	glEnd();
	
	/* 3 x 3 Zylinder */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_TRIANGLES);
	        glColor4f(0.00f, 0.50f, 1.00f, 1.0f);
	        glVertex3f( 0.30f, -0.40f -zylscale1, -0.20f );
	        glVertex3f( 0.00f, -0.37f -zylscale2, -0.20f );
	        glVertex3f(-0.30f, -0.40f -zylscale1, -0.20f );
	      
	        glVertex3f( 0.30f, -0.37f -zylscale2, -0.50f );
	        glVertex3f( 0.00f, -0.40f -zylscale1, -0.50f );
	        glVertex3f(-0.30f, -0.37f -zylscale2, -0.50f );
	        
	        glVertex3f( 0.30f, -0.40f -zylscale1, -0.80f );
	        glVertex3f( 0.00f, -0.37f -zylscale2, -0.80f );
	        glVertex3f(-0.30f, -0.40f -zylscale1, -0.80f );
	glEnd();
	#endif
}

/*---------------------------------------------------------------------------*/

/* Render Cockpit */
void Motor()
{			
	/* PlaneView */
	CameraLook();
	Plane(xPlane, yPlane, zPlane);
	
	/* Line & Point */
	glLineWidth(2);
	glPointSize(15);

	#ifdef MOT
	/* Begin Motor ( 2. GL_LINE / 2. GL_FILL ) */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL); 
	glBegin(GL_TRIANGLES);

		/* Rost Metalic */
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.0f,  -0.4f,  0.0f );
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.0f,  -0.4f, -0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f( 0.5f,  -0.4f, -0.5f );
		
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.0f,  -0.4f,  0.0f );
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.0f,  -0.4f, -0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f(-0.5f,  -0.4f, -0.5f );
		
		/* 4 x 4 */
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f( 0.5f,  -0.4f, -0.5f );
		glVertex3f( 0.5f,  -0.4f, -1.0f );

		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f( 0.0f,  -0.4f, -1.0f );
		glVertex3f( 0.5f,  -0.4f, -1.0f );
		
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f(-0.5f,  -0.4f, -0.5f );
		glVertex3f(-0.5f,  -0.4f, -1.0f );

		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.0f,  -0.4f, -0.5f );
		glVertex3f( 0.0f,  -0.4f, -1.0f );
		glVertex3f(-0.5f,  -0.4f, -1.0f );
		
		/* Corner */
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 1.0f,  -0.4f, -0.5f );
		glVertex3f( 0.5f,  -0.4f, -0.5f );
		glVertex3f( 0.5f,  -0.4f, -1.0f );
		
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f(-1.0f,  -0.4f, -0.5f );
		glVertex3f(-0.5f,  -0.4f, -0.5f );
		glVertex3f(-0.5f,  -0.4f, -1.0f );
		
		/* Right */
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 1.0f,  -0.4f,  0.0f );
		glVertex3f( 1.0f,  -0.4f, -0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.5f,  -0.4f, -0.5f );
		glVertex3f( 1.0f,  -0.4f, -0.5f );
		
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 1.0f,  -0.4f,  0.0f );
		glVertex3f( 1.0f,  -0.4f,  0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 0.5f,  -0.4f,  0.0f );
		glVertex3f( 0.5f,  -0.4f,  0.5f );
		glVertex3f( 1.0f,  -0.4f,  0.5f );
		
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f( 1.0f,  -0.4f,  0.5f );
		glVertex3f( 0.5f,  -0.4f,  0.5f );
		glVertex3f( 0.5f,  -0.4f,  1.0f );

		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f( 1.0f,  -0.4f,  0.5f );
		glVertex3f( 1.0f,  -0.4f,  1.0f );
		glVertex3f( 0.5f,  -0.4f,  1.0f );
		
		/* Left */
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f(-1.0f,  -0.4f,  0.0f );
		glVertex3f(-1.0f,  -0.4f, -0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f(-0.5f,  -0.4f, -0.5f );
		glVertex3f(-1.0f,  -0.4f, -0.5f );
		
		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f(-1.0f,  -0.4f,  0.0f );
		glVertex3f(-1.0f,  -0.4f,  0.5f );

		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f(-0.5f,  -0.4f,  0.0f );
		glVertex3f(-0.5f,  -0.4f,  0.5f );
		glVertex3f(-1.0f,  -0.4f,  0.5f );
		
		glColor4f(0.15f, 0.15f, 0.15f, 1.0f);
		glVertex3f(-1.0f,  -0.4f,  0.5f );
		glVertex3f(-0.5f,  -0.4f,  0.5f );
		glVertex3f(-0.5f,  -0.4f,  1.0f );

		glColor4f(0.10f, 0.10f, 0.10f, 1.0f);
		glVertex3f(-1.0f,  -0.4f,  0.5f );
		glVertex3f(-1.0f,  -0.4f,  1.0f );
		glVertex3f(-0.5f,  -0.4f,  1.0f );
	glEnd();
	
	/* Render Cockpit */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_QUADS);
	
		glColor4f( 0.15f, 0.15f, 0.15f, 1.0f );	
		glVertex3f(-0.5f, -0.5f, 0.0f );
		glVertex3f( 0.5f, -0.5f, 0.0f );
		glVertex3f( 0.5f, -0.4f, 0.0f );
		glVertex3f(-0.5f, -0.4f, 0.0f );
		
		glColor4f( 0.10f, 0.10f, 0.10f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 0.0f );
		glVertex3f( 0.5f, -0.4f, 0.0f );
		glVertex3f( 0.5f, -0.4f, 1.0f );
		
		glColor4f( 0.10f, 0.10f, 0.10f, 1.0f );
		glVertex3f(-0.5f, -0.5f, 1.0f );
		glVertex3f(-0.5f, -0.5f, 0.0f );
		glVertex3f(-0.5f, -0.4f, 0.0f );
		glVertex3f(-0.5f, -0.4f, 1.0f );
	glEnd(); 
	#endif
}

/*---------------------------------------------------------------------------*/

/* Render Cockpit */
void Cockpit()
{		
	/* PlaneView */
	CameraLook();
	Plane(xPlane, yPlane, zPlane);
	
	/* Line & Point */
	glLineWidth(2);
	glPointSize(15);
	
	#ifdef COK
	/* Render Cockpit */
	glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
	glBegin(GL_QUADS);
	
		/* Cockpit */
		glColor4f( 0.90f, 0.90f, 0.90f, 1.0f);
		glVertex3f(-0.3f, -0.2f, 0.3f );
		glVertex3f( 0.3f, -0.2f, 0.3f );
		glVertex3f( 0.3f,  0.3f, 0.3f );
		glVertex3f(-0.3f,  0.3f, 0.3f );
		
		/* Line */
		glColor4f( 0.1f, 0.1f, 0.1f, 1.0f );	
		glVertex3f(-0.5f, -0.5f, 0.0f );
		glVertex3f( 0.5f, -0.5f, 0.0f );
		glVertex3f( 0.5f,  0.5f, 0.0f );
		glVertex3f(-0.5f,  0.5f, 0.0f );
		
		glVertex3f(-0.5f, -0.5f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 0.0f );
		glVertex3f(-0.5f, -0.5f, 0.0f );
		
		glVertex3f(-0.5f,  0.5f, 1.0f );
		glVertex3f( 0.5f,  0.5f, 1.0f );
		glVertex3f( 0.5f,  0.5f, 0.0f );
		glVertex3f(-0.5f,  0.5f, 0.0f );
		
		/* Terminal */
		glColor4f( 0.80f, 0.40f, 0.25f, 1.0f);	
		glVertex3f(-2.0f, 20.54f + rootY, 0.5f -viewZ );
		glVertex3f( 2.0f, 20.54f + rootY, 0.5f -viewZ );
		glVertex3f( 2.0f, 20.50f + rootY, 0.5f -viewZ );
		glVertex3f(-2.0f, 20.50f + rootY, 0.5f -viewZ );
	glEnd();
	
	/* Render Points */
	glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
	glBegin(GL_POINTS);
	/*glBegin(GL_QUADS);*/
		
		/* Point */
		glColor4f(  0.00f, 1.00f, 0.00f, 1.0f);	
		glVertex3f(-0.45f, -0.45f, 0.15f );
		glVertex3f( 0.45f, -0.45f, 0.15f );
		glVertex3f( 0.45f,  0.45f, 0.15f );
		glVertex3f(-0.45f,  0.45f, 0.15f );
		
		glColor4f(  1.00f, 0.50f, 0.00f, 1.0f);
		glVertex3f(-0.45f, -0.45f, 0.99f );
		glVertex3f( 0.45f, -0.45f, 0.99f );
		glVertex3f( 0.45f, -0.45f, 0.15f );
		glVertex3f(-0.45f, -0.45f, 0.15f );
		
		glColor4f(  1.00f, 1.00f, 0.00f, 1.0f);
		glVertex3f(-0.45f,  0.45f, 0.99f );
		glVertex3f( 0.45f,  0.45f, 0.99f );
		glVertex3f( 0.45f,  0.45f, 0.15f );
		glVertex3f(-0.45f,  0.45f, 0.15f );
	glEnd();
	
	/* Render Cockpit */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_POINTS);
	/*glBegin(GL_QUADS);*/
	
		/* Red */
		glColor4f( 1.0f, 0.0f, 0.0f, 1.0f );
		glVertex3f(-0.3f,  0.3f, 0.31f );
		/* Blue */
                glColor4f( 0.0f, 0.0f, 1.0f, 1.0f );
                glVertex3f( 0.3f,  0.3f, 0.31f );
		/* Green */
		glColor4f( 0.0f, 1.0f, 0.0f, 1.0f );
		glVertex3f( 0.3f, -0.2f, 0.31f );
		/* Black */
                glColor4f( 0.0f, 0.0f, 0.0f, 1.0f );
                glVertex3f(-0.3f, -0.2f, 0.31f );
	glEnd();
	
	/* Render Quads */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_QUADS);
	
		/* Instruments */
		glColor4f( 0.0f, 0.0f, 0.0f, 0.4f);		
		glVertex3f(-0.3f, -0.2f, 0.3f );
		glVertex3f( 0.3f, -0.2f, 0.3f );
		glVertex3f( 0.3f,  0.3f, 0.3f );
		glVertex3f(-0.3f,  0.3f, 0.3f );
		
		/* Ebene Down */
		glColor4f( 0.20f, 0.20f, 0.20f, 1.0f );
		glVertex3f(-0.5f, -0.5f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 1.0f );
		glVertex3f( 0.5f, -0.5f, 0.0f );
		glVertex3f(-0.5f, -0.5f, 0.0f );
		
		/* Ebene Up */
		glColor4f( 0.20f, 0.20f, 0.20f, 1.0f );
		glVertex3f( 0.5f, 0.5f, 1.0f );
		glVertex3f(-0.5f, 0.5f, 1.0f );
		glVertex3f(-0.5f, 0.5f, 0.0f );
		glVertex3f( 0.5f, 0.5f, 0.0f );
		
		/* Terminal */
		glColor4f( 0.05f, 0.10f, 0.15f, 0.9f);
		glVertex3f(-2.0f, 20.50f + rootY, 0.5f -viewZ );
		glVertex3f( 2.0f, 20.50f + rootY, 0.5f -viewZ );
		glVertex3f( 2.0f, 20.54f + rootY, 0.5f -viewZ );
		glVertex3f(-2.0f, 20.54f + rootY, 0.5f -viewZ );

		glColor4f( 0.0f, 0.0f, 0.0f, 0.8f);
		glVertex3d(-2.0f, 20.50f + rootY, 0.5f -viewZ );
		glVertex3d( 2.0f, 20.50f + rootY, 0.5f -viewZ );
		glVertex3d( 2.0f, 21.00f + rootY, 0.5f -viewZ );
		glVertex3d(-2.0f, 21.00f + rootY, 0.5f -viewZ );
	glEnd();
	#endif
	
	/* Render Quads */
	glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
	glBegin(GL_QUADS);
		/* Night Look */
		glColor4f( 0.00f, 1.00f, 0.00f, 0.0f -nightV);
		glVertex3d(-2.0f,-1.0f, 0.5f -viewZ );
		glVertex3d( 2.0f,-1.0f, 0.5f -viewZ );
		glVertex3d( 2.0f, 1.0f, 0.5f -viewZ );
		glVertex3d(-2.0f, 1.0f, 0.5f -viewZ );
		glColor4f( 1.00f, 1.00f, 1.00f, 1.0f);
	glEnd();	
	glDisable(GL_DEPTH_TEST);
	glDisable(GL_BLEND);
}

/*---------------------------------------------------------------------------*/

/* Process Event */
void process_event2(XEvent report)
{   
	/* Float Value */
	float value0 = 0.00f;
	float value1 = 0.10f;
	float value2 = 0.20f;
	float value5 = 0.50f;
	float value20 = 20.50f;
	
	KeySym key;
	key = XLookupKeysym (&report.xkey, 0);
	
	/* Keyboard Control Keys */	
	switch(key)
	{		
		case XK_x: 
		viewZ =  value0; 
		break;

		case XK_y: 
		viewZ = -value5;
		break;
		
		case XK_m: 
		nightV = +value2;
		break;

		case XK_n: 
		nightV = -value2;
		break;

		case XK_F1: 
		rootY = -value20; 
		break;

		case XK_F2: 
		rootY = +value20; 
		break;

		case XK_F3: 
		scaPlane = -value1;
		break;

		case XK_F4: 
		scaPlane = value0;
		break;

		case XK_Escape: 
		closeWin(); 
		break;
	}
}

/*---------------------------------------------------------------------------*/

