/*********************************************************************
*                                                                    *          
*                              FLY                                   *
*                           --E#Y#E--				     *
*                         ===MUSCLE===                               *
*                                                                    *
*********************************************************************/
/* Header Files */
#include "uniform.h"

#define MAX 2048

/*-------------------------------------------------------------------------*/

/* Create Shader */
void CreateShader()
{	
	/* Create Shader */
	vertexShader.filename = glCreateShader(GL_VERTEX_SHADER);
	fragmentShader.filename = glCreateShader(GL_FRAGMENT_SHADER);

	/* Open Shader */
	vertexShader.source = open("UNI/fly.vert",O_RDONLY);
	fragmentShader.source = open("UNI/fly.frag",O_RDONLY);
	/* Read File */
	read(vertexShader.source, vert, MAX);
	read(fragmentShader.source, frag, MAX);
	/* Send to Source */
	glShaderSource(vertexShader.id, vert[MAX], &tmp, NULL);
	glShaderSource(fragmentShader.id, frag[MAX], &tmp, NULL);
	
	/* Compile vertexShader */
	glCompileShader(vertexShader.id);
	glGetShaderiv(vertexShader.id, GL_COMPILE_STATUS, &vertexShader.result);	
	if(vertexShader.source)
	{
		printf("Could not Compile Shader. %d ", vertexShader.id);
		
	}
	glGetShaderiv(vertexShader.id, GL_INFO_LOG_LENGTH, &vertexShader.info);
	if(vertexShader.info)
	{	
		glGetShaderInfoLog(vertexShader.id, vert[MAX], 
				&vertexShader.info, &vertexShader.log[0]);
		printf("Shader contains Errors! %s ", vertexShader.log);	
	}

	/* Compile fragmentShader */
	glCompileShader(fragmentShader.id);
	glGetShaderiv(fragmentShader.id, GL_COMPILE_STATUS, &fragmentShader.result);	
	if(fragmentShader.source)
	{
		printf("Could not Compile Shader. %d ", fragmentShader.id);
	}
	glGetShaderiv(fragmentShader.id, GL_INFO_LOG_LENGTH, &fragmentShader.info);
	if(fragmentShader.info)
	{	
		glGetShaderInfoLog(fragmentShader.id, frag[MAX], 
				&fragmentShader.info, &fragmentShader.log[0]);
		printf("Shader contains Errors! %s ", fragmentShader.log);
	}
}

/*-------------------------------------------------------------------------*/

/* Create Program */	
void CreateProgram(GLuint shaderProgram)
{	
	/* Create Program */
	shaderProgram = glCreateProgram();

	/* Attach the Shaders to Object */
	glAttachShader(shaderProgram, vertexShader.id);
	glAttachShader(shaderProgram, fragmentShader.id);
	
	/* Link the Program */	
	glLinkProgram(shaderProgram);
	
	/* Bind Program */
	glUseProgram(shaderProgram);
}

/*-------------------------------------------------------------------------*/

/* Location */
void Location(GLuint shaderProgram, unsigned int index, const char* name)
{
	/* Get Location */
	vertexPosition = glGetAttribLocation(shaderProgram, "a_Vertex");
	colorPosition = glGetAttribLocation(shaderProgram, "a_Color");
	normalPosition = glGetAttribLocation(shaderProgram, "a_TexCoord");
	location = glGetAttribLocation(shaderProgram, name);

	/* Bind Location */
	glBindAttribLocation(shaderProgram, vertexPosition, name);
	glBindAttribLocation(shaderProgram, colorPosition, name);
	glBindAttribLocation(shaderProgram, normalPosition, name);
	glBindAttribLocation(shaderProgram, location, name);
}	

/*-------------------------------------------------------------------------*/

/* Uniform */
void Uniform(GLuint shaderProgram, const char* name, const float matrix)
{
        /* Get Uniform */
        glUniform4f(glGetUniformLocation(shaderProgram, "outColor"), 0, 0, 0, 1);
        glUniform1f(glGetUniformLocation(shaderProgram, "texture0"), 0);

	location = glGetUniformLocation(shaderProgram, name);
	glUniform1f(location, matrix);
}

/*-------------------------------------------------------------------------*/

/* Uniform 4x4 */
void Uniform4x4(GLuint shaderProgram, const char* name, char transpose, const float* matrix)
{
	/* Get Location */
	transpose = 0;

        /* Get Uniform 4x4 */
	/*fudgeLocation = glGetUniformLocation(shaderProgram, "fudge_factor");*/
	projectionMatrix = glGetUniformLocation(shaderProgram, "projection_matrix");
	modelViewMatrix = glGetUniformLocation(shaderProgram, "modelview_matrix");
	location = glGetUniformLocation(shaderProgram, name);

	/* Uniform 4x4 */
        /*glUniformMatrix4fv(fudgeLocation, 1, transpose, matrix);*/
	glUniformMatrix4fv(projectionMatrix, 1, transpose, matrix);
	glUniformMatrix4fv(modelViewMatrix, 1, transpose, matrix);
	glUniformMatrix4fv(location, 1, transpose, matrix);
}

/*-------------------------------------------------------------------------*/

/* Delete Shader */
void DeleteShader(GLuint shaderProgram)
{
	/* Delete the Shaders */
	glDetachShader(shaderProgram, vertexShader.id);	
	glDetachShader(shaderProgram, fragmentShader.id);
	glDeleteShader(vertexShader.id);
	glDeleteShader(fragmentShader.id);
	glDeleteShader(shaderProgram);

	/* File Close */
	close(vertexShader.source);
	close(fragmentShader.source);	
}

/*-------------------------------------------------------------------------*/



