/*********************************************************************
*                                                                    *          
*                              FLY                                   *
*                           --E#Y#E--				     *
*                         ===MUSCLE===                               *
*                                                                    *
*********************************************************************/
/* Header Files */
#include "uniform.h"

#define MAX 2048

//---------------------------------------------------------------------------

/* Create Shader */
void UNIFORM::CreateShader()
{
	/* Create Shader */
	vertexShader.id= glCreateShader(GL_VERTEX_SHADER);
	fragmentShader.id = glCreateShader(GL_FRAGMENT_SHADER);	

	/* Open Shader */
	vertShader.open("UNI/fly.vert");
	fragShader.open("UNI/fly.frag");
	/* Read File */
	vertShader.read(vert, MAX);
	fragShader.read(frag, MAX);
	/* Send to Source */
	glShaderSource(vertexShader.id, vert[MAX], &tmp, NULL);
	glShaderSource(fragmentShader.id, frag[MAX], &tmp, NULL);
	
	/* Compile vertexShader */
	glCompileShader(vertexShader.id);
	glGetShaderiv(vertexShader.id, GL_COMPILE_STATUS, &vertexShader.result);	
	if(vertexShader.result)
	{
		printf("Could not Compile Shader. %d ", vertexShader.id);
		
	}
	glGetShaderiv(vertexShader.id, GL_INFO_LOG_LENGTH, &vertexShader.info);
	if(vertexShader.info)
	{	
		glGetShaderInfoLog(vertexShader.id, 1, &vertexShader.info, &vertexShader.log[0]);
		printf("Shader contains Errors! %s ", vertexShader.log);	
	}

	/* Compile fragmentShader */
	glCompileShader(fragmentShader.id);
	glGetShaderiv(fragmentShader.id, GL_COMPILE_STATUS, &fragmentShader.result);	
	if(fragmentShader.result)
	{
		printf("Could not Compile Shader. %d ", fragmentShader.id);
	}
	glGetShaderiv(fragmentShader.id, GL_INFO_LOG_LENGTH, &fragmentShader.info);
	if(fragmentShader.info)
	{	
		glGetShaderInfoLog(fragmentShader.id, 1, &fragmentShader.info, &fragmentShader.log[0]);
		printf("Shader contains Errors! %s ", fragmentShader.log);
	}
}

//---------------------------------------------------------------------------

/* Create Program */	
void UNIFORM::CreateProgram(GLuint shaderProgram)
{	
	/* Create Program */
	shaderProgram = glCreateProgram();
	
	/* Attach the Shaders to Object */
	glAttachShader(shaderProgram, vertexShader.id);
	glAttachShader(shaderProgram, fragmentShader.id);
	
	/* Link the Program */	
	glLinkProgram(shaderProgram);

	/* Bind Program */
	glUseProgram(shaderProgram);
}

//---------------------------------------------------------------------------

/* Location */
void UNIFORM::Location(GLuint shaderProgram, unsigned int index, const char* name)
{
        /* Get Location */
        vertexPosition = glGetAttribLocation(shaderProgram, "a_Vertex");
        colorPosition = glGetAttribLocation(shaderProgram, "a_Color");
        normalPosition = glGetAttribLocation(shaderProgram, "a_TexCoord");
        location = glGetAttribLocation(shaderProgram, name);

        /* Bind Location */
        glBindAttribLocation(shaderProgram, vertexPosition, name);
        glBindAttribLocation(shaderProgram, colorPosition, name);
        glBindAttribLocation(shaderProgram, normalPosition, name);
        glBindAttribLocation(shaderProgram, location, name);
}	

//---------------------------------------------------------------------------

/* Uniform */
void UNIFORM::Uniform(GLuint shaderProgram, const char* name, const float matrix)
{
        /* Get Uniform */
        glUniform4f(glGetUniformLocation(shaderProgram, "outColor"), 0, 0, 0, 1);
        glUniform1f(glGetUniformLocation(shaderProgram, "texture0"), 0);

	/* Get Uniform */
	location = glGetUniformLocation(shaderProgram, name);
	glUniform1f(location, matrix);
}

//---------------------------------------------------------------------------

/* Uniform 4x4 */
void UNIFORM::Uniform4x4(GLuint shaderProgram, const char* name, bool transpose, const float* matrix)
{
        /* Get Location */
        transpose = 0;

        /* Get Uniform 4x4 */
        //fudgeLocation = glGetUniformLocation(shaderProgram, "fudge_factor");
        projectionMatrix = glGetUniformLocation(shaderProgram, "projection_matrix");
        modelViewMatrix = glGetUniformLocation(shaderProgram, "modelview_matrix");
        location = glGetUniformLocation(shaderProgram, name);

        /* Uniform 4x4 */
        //glUniformMatrix4fv(fudgeLocation, 1, transpose, matrix);
        glUniformMatrix4fv(projectionMatrix, 1, transpose, matrix);
        glUniformMatrix4fv(modelViewMatrix, 1, transpose, matrix);
        glUniformMatrix4fv(location, 1, transpose, matrix);
}

//---------------------------------------------------------------------------

/* Delete Shader */
void UNIFORM::DeleteShader(GLuint shaderProgram)
{
	/* Delete the Shaders */
	glDetachShader(shaderProgram, vertexShader.id);	
	glDetachShader(shaderProgram, fragmentShader.id);
	glDeleteShader(vertexShader.id);
	glDeleteShader(fragmentShader.id);
	glDeleteShader(shaderProgram);
	
	/* File Close */
	vertShader.close();
	fragShader.close();	
}

//---------------------------------------------------------------------------



