/*********************************************************************
*                                                                    *          
*                              FLY                                   *
*                           --E#Y#E--				     *
*                         (==MUSCLE==)                               *
*                                                                    *
*********************************************************************/

/* C++ Header Files */
#include <map>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <fstream>
#include <iostream>
#include <vector>
#include <cmath>
/* X11 */
#include <X11/keysym.h>
#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
/* OpenGL */
#include <GL/glew.h>
#include <GL/gl.h>
#include <GL/glx.h>
#include <GL/glu.h>
/* Flysimulator */
#include "HELP/help.h"
#include "WIN/win.h"
#include "FPS/fps.h"
#include "LEO/point.h"
#include "UNI/uniform.h"
#include "OGL/opengl.h"
#include "OGL/cockpit.h"


/* Define Key */
#define XK_space                         0x0020
#define XK_Escape                        0xff1b
#define XK_F1                            0xffbe
#define XK_F2                            0xffbf
#define XK_F3				 0xffc0
#define XK_F4				 0xffc1
#define XK_F5				 0xffc2
#define XK_F6				 0xffc3
#define XK_F7				 0xffc4
#define XK_F8				 0xffc5
#define XK_Left                          0xff51 
#define XK_Right                         0xff53
#define XK_Up                            0xff52  
#define XK_Down                          0xff54  
#define XK_a                             0x0061
#define XK_b                             0x0062
#define XK_d                             0x0064
#define XK_e                             0x0065
#define XK_g                             0x0067
#define XK_h                             0x0068
#define XK_q                             0x0071 
#define XK_s                             0x0073 
#define XK_t                             0x0074 
#define XK_w                             0x0077
#define XK_z                             0x007a
#define XK_n                             0x006e
#define XK_m                             0x006d

//---------------------------------------------------------------------------

bool wide, grid, fversion, fhelp = false;
float dt;

WIND wind;
FLY fly;
MOD mod;
FPS fps;
LEO leo;
HELP help;

//---------------------------------------------------------------------------

/* Main Program */
int main (int egac, char **egav) 
{
	/* Settings */	
	int n = 0;
	int f = 0;
	
	/* Notation */
	int vonA  =  0;
        int vonX  =  0;
	
	for(n = 0; n < egac; n++)
	{
		for(f = 0; f < egav[n][f]; ++f)
		{
			switch(egav[n][f])    
			{
				case 'F':
				wide = true;
				break;
				
				case 'G':
				grid = true;
				break;				
				
				case 'v':
				fversion = true;
				break;
				
				case 'h':
				fhelp = true;
				break;
			}
		}
	}
	
	//-------------------------------------------------------------------

        /* Window */
        if(grid)
        {
	        /* Create Window */
	        wind.createWin(wide);
	        fps.InitTimeCounter();
	        fly.loadTexture();
	}
	
	/* Render */
	while(grid)
	{	
	        /* Landscape */	  	
		fly.initGrid();
		fly.Landscape();
		
	 	/* Cord */
		leo.initCord();
	        leo.Cord(vonA, vonX);
	        
		/* Cockpit */
		mod.Speed(dt);
		mod.Zylinder();
		mod.Motor();
		mod.Cockpit();
		
		/* Display */
		wind.perspective();
		wind.eventloop();
		wind.loadFont();
		
		/* FPS */
		fps.CalculateFPS();
		fps.UpdateTimeCounter(dt);
	}
	 
	/* Show Help Desk */
	if(fhelp)
	{
		help.Desk(egac);
	}

	/* Display Version */
	if(fversion)
	{
		help.version();
	}
	 
	return 0;
}

//---------------------------------------------------------------------------


